package parkomat.ui.javafx;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import javafx.application.Application;
import javafx.scene.Scene;
import javafx.scene.paint.Color;
import javafx.stage.Stage;
import parkomat.model.Tariffa;
import parkomat.model.TariffaValida;
import parkomat.persistence.BadFileFormatException;
import parkomat.persistence.TariffeReader;
import parkomat.persistence.MyTariffeReader;
import parkomat.ui.controller.Controller;
import parkomat.ui.controller.MyController;

public class ParkomatApplication extends Application {

	private Controller controller;

	public void start(Stage stage) {
		controller = createController();
		if (controller == null) {
			Controller.alert("Errore irrecuperabile", "Errore nella creazione del controller", "Addio");
			System.exit(1);
		}
		stage.setTitle("Park-O-Mat");
		ParkomatPane root = new ParkomatPane(controller);
		
		Scene scene = new Scene(root, 750, 660, Color.ALICEBLUE);
		stage.setScene(scene);
		stage.show();
	}

	protected Controller createController() {
		TariffeReader tariffeReader = null;
		Map<String,Tariffa> mappaTariffe = null;
		try {
			tariffeReader = new MyTariffeReader();
			mappaTariffe = tariffeReader.leggiTariffe(new FileReader("Tariffe.txt"));
		} catch (FileNotFoundException e) {
			Controller.alert("Errore di I/O", "Errore nell'apertura del file tariffe", e.getMessage());
			return null;
		}
		catch (IOException e) {
			Controller.alert("Errore di I/O", "Errore durante la lettura del file tariffe", e.getMessage());
			return null;
		}
		catch (BadFileFormatException e) {
			Controller.alert("Errore di formato", "Formato errato nelle tariffe", e.getMessage());
			return null;
		}
		return new MyController(generaMappaTariffeValide(mappaTariffe));
	}

	protected Map<String, TariffaValida> generaMappaTariffeValide(Map<String, Tariffa> mappaTariffe) {
		Map<String, TariffaValida> result = new HashMap<>();
		for(String n : mappaTariffe.keySet()) result.put(n,  new TariffaValida(mappaTariffe.get(n)));
		return result;
	}

	public static void main(String[] args) {
		launch(args);
	}

}
